@@ -22,7 +22,16 @@ if ret:
     exit(ret)
 
 ret = subprocess.call(
-    [os.path.join(vedir, 'bin', 'pip'), "install", "-E", vedir,
+    [os.path.join(vedir, 'bin', 'pip'), "install",
+     "--index-url=http://pypi.ccnmtl.columbia.edu/",
+     "wheel==0.21.0"])
+
+if ret:
+    exit(ret)
+
+ret = subprocess.call(
+    [os.path.join(vedir, 'bin', 'pip'), "install",
+     "--use-wheel",
      "--index-url=http://pypi.ccnmtl.columbia.edu/",
      "--requirement", os.path.join(pwd, "requirements.txt")])
 
